pub struct VotingValidationVersions {
pub allow_other_contenders_time_mainnet_ms: u64,
pub allow_other_contenders_time_testing_ms: u64,
pub votes_allowed_per_masternode: u16,
}Fields
allow_other_contenders_time_mainnet_ms: u64How long do we allow other contenders to join a contest after the first contender
allow_other_contenders_time_testing_ms: u64How long do we allow other contenders to join a contest after the first contender in a testing environment
votes_allowed_per_masternode: u16How many votes do we allow from the same masternode?