pub struct FeeVersionFieldsBeforeVersion4 {
pub uses_version_fee_multiplier_permille: Option<u64>,
pub storage: FeeStorageVersion,
pub signature: FeeSignatureVersion,
pub hashing: FeeHashingVersionBeforeVersion11,
pub processing: FeeProcessingVersionFieldsBeforeVersion1Point4,
pub data_contract: FeeDataContractValidationVersion,
pub state_transition_min_fees: StateTransitionMinFeesBeforeProtocolVersion11,
pub vote_resolution_fund_fees: VoteResolutionFundFees,
}Fields
uses_version_fee_multiplier_permille: Option<u64>storage: FeeStorageVersionsignature: FeeSignatureVersionhashing: FeeHashingVersionBeforeVersion11processing: FeeProcessingVersionFieldsBeforeVersion1Point4data_contract: FeeDataContractValidationVersionstate_transition_min_fees: StateTransitionMinFeesBeforeProtocolVersion11vote_resolution_fund_fees: VoteResolutionFundFeesTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for FeeVersionFieldsBeforeVersion4
impl<'__de, __Context> BorrowDecode<'__de, __Context> for FeeVersionFieldsBeforeVersion4
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for FeeVersionFieldsBeforeVersion4
impl Clone for FeeVersionFieldsBeforeVersion4
Sourcefn clone(&self) -> FeeVersionFieldsBeforeVersion4
fn clone(&self) -> FeeVersionFieldsBeforeVersion4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<__Context> Decode<__Context> for FeeVersionFieldsBeforeVersion4
impl<__Context> Decode<__Context> for FeeVersionFieldsBeforeVersion4
Sourceimpl Default for FeeVersionFieldsBeforeVersion4
impl Default for FeeVersionFieldsBeforeVersion4
Sourcefn default() -> FeeVersionFieldsBeforeVersion4
fn default() -> FeeVersionFieldsBeforeVersion4
Returns the “default value” for a type. Read more
Sourceimpl From<FeeVersionFieldsBeforeVersion4> for FeeVersion
impl From<FeeVersionFieldsBeforeVersion4> for FeeVersion
Sourcefn from(value: FeeVersionFieldsBeforeVersion4) -> Self
fn from(value: FeeVersionFieldsBeforeVersion4) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for FeeVersionFieldsBeforeVersion4
impl PartialEq for FeeVersionFieldsBeforeVersion4
Sourcefn eq(&self, other: &FeeVersionFieldsBeforeVersion4) -> bool
fn eq(&self, other: &FeeVersionFieldsBeforeVersion4) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for FeeVersionFieldsBeforeVersion4
impl StructuralPartialEq for FeeVersionFieldsBeforeVersion4