FromPlatformVersioned

Trait FromPlatformVersioned 

pub trait FromPlatformVersioned<T>: Sized {
    // Required method
    fn from_platform_versioned(
        value: T,
        platform_version: &PlatformVersion,
    ) -> Self;
}
A trait for converting a value of type T into Self using a provided PlatformVersion.

This trait is infallible and guarantees a valid result for supported versions.

Required Methods

fn from_platform_versioned(value: T, platform_version: &PlatformVersion) -> Self

Performs the conversion.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors