pub struct FeeDataContractRegistrationVersion {
pub base_contract_registration_fee: u64,
pub document_type_registration_fee: u64,
pub document_type_base_non_unique_index_registration_fee: u64,
pub document_type_base_unique_index_registration_fee: u64,
pub document_type_base_contested_index_registration_fee: u64,
pub token_registration_fee: u64,
pub token_uses_perpetual_distribution_fee: u64,
pub token_uses_pre_programmed_distribution_fee: u64,
pub search_keyword_fee: u64,
}Expand description
These are the fee costs for various actions excluding validation Re-Validation will happen on data contract update which is why we don’t bundle them together.
Fields
base_contract_registration_fee: u64document_type_registration_fee: u64document_type_base_non_unique_index_registration_fee: u64document_type_base_unique_index_registration_fee: u64document_type_base_contested_index_registration_fee: u64All contested indexes are unique, but if the index is contested you only apply this fee
token_registration_fee: u64token_uses_perpetual_distribution_fee: u64token_uses_pre_programmed_distribution_fee: u64search_keyword_fee: u64Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for FeeDataContractRegistrationVersion
impl<'__de, __Context> BorrowDecode<'__de, __Context> for FeeDataContractRegistrationVersion
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for FeeDataContractRegistrationVersion
impl Clone for FeeDataContractRegistrationVersion
Sourcefn clone(&self) -> FeeDataContractRegistrationVersion
fn clone(&self) -> FeeDataContractRegistrationVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<__Context> Decode<__Context> for FeeDataContractRegistrationVersion
impl<__Context> Decode<__Context> for FeeDataContractRegistrationVersion
Sourceimpl Default for FeeDataContractRegistrationVersion
impl Default for FeeDataContractRegistrationVersion
Sourcefn default() -> FeeDataContractRegistrationVersion
fn default() -> FeeDataContractRegistrationVersion
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for FeeDataContractRegistrationVersion
impl PartialEq for FeeDataContractRegistrationVersion
Sourcefn eq(&self, other: &FeeDataContractRegistrationVersion) -> bool
fn eq(&self, other: &FeeDataContractRegistrationVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for FeeDataContractRegistrationVersion
impl StructuralPartialEq for FeeDataContractRegistrationVersion