pub struct VoteResolutionFundFees {
pub contested_document_vote_resolution_fund_required_amount: u64,
pub contested_document_vote_resolution_unlock_fund_required_amount: u64,
pub contested_document_single_vote_cost: u64,
}Fields
contested_document_vote_resolution_fund_required_amount: u64This is the amount that will be deducted from an identity and used to pay for voting
contested_document_vote_resolution_unlock_fund_required_amount: u64This is the amount that will be deducted from an identity and used to pay for voting if we are currently locked
contested_document_single_vote_cost: u64This is the amount that a single vote will cost